@@ -289,6 +289,62 @@ def escape_regex(value):
         value = value.replace(char, f"\\{char}")
     return value
 
+def strip_any(value,chars,side='both'):
+    '''
+        Strips characters/strings from the beginning,end or both sides of a string.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {str}
+            The value to be formatted
+        `chars` {list}
+            A list of strings to be stripped from the value
+        [`side`='both'] {str}
+            Can be "left", "right", "both"
+
+        Return {str}
+        ----------------------
+        The formatted value.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 02-04-2022 10:25:04
+        `memberOf`: string_format
+        `version`: 1.0
+        `method_name`: strip_any
+    '''
+    new_value = value
+    cycle = True
+    if side in ["both","left"]:
+        cycle = True
+        while cycle is True:
+            matchFound = False
+            for char in chars:
+                if new_value.startswith(char):
+                    new_value = new_value[len(char):]
+                    matchFound = True
+                else:
+                    continue
+            if matchFound is False:
+                cycle = False
+    if side in ["both","right"]:
+        cycle = True
+        while cycle is True:
+            matchFound = False
+            for char in chars:
+                if new_value.endswith(char):
+                    new_value = new_value[:-len(char)]
+                    matchFound = True
+                else:
+                    continue
+            if matchFound is False:
+                cycle = False
+    return new_value
+
+print(f">{strip_any(', #hugeDongboobs.d ,#',[' ','#',',','hugeDong'])}<")
 
 def strip_end(text, suffix):
     if suffix and text.endswith(suffix):
